@@ -1,6 +1,6 @@
 # Roundup Issue Tracker configuration support
 #
-# $Id: configuration.py,v 1.50 2007/11/14 14:57:47 schlatterbeck Exp $
+# $Id$
 #
 __docformat__ = "restructuredtext"
 
@@ -478,12 +478,16 @@ SETTINGS = (
             "specified above.  If this option is not set, all static\n"
             "files are taken from the TEMPLATES directory"),
         (MailAddressOption, "admin_email", "roundup-admin",
-            "Email address that roundup will complain to"
-            " if it runs into trouble."),
+            "Email address that roundup will complain to if it runs\n"
+            "into trouble.\n"
+            "If no domain is specified then the config item\n"
+            "mail -> domain is added."),
         (MailAddressOption, "dispatcher_email", "roundup-admin",
             "The 'dispatcher' is a role that can get notified\n"
             "of new items to the database.\n"
-            "It is used by the ERROR_MESSAGES_TO config setting."),
+            "It is used by the ERROR_MESSAGES_TO config setting.\n"
+            "If no domain is specified then the config item\n"
+            "mail -> domain is added."),
         (Option, "email_from_tag", "",
             "Additional text to include in the \"name\" part\n"
             "of the From: address used in nosy messages.\n"
@@ -538,7 +542,8 @@ SETTINGS = (
             "that is required to get to the home page of the tracker.\n"
             "You MUST include a trailing '/' in the URL."),
         (MailAddressOption, "email", "issue_tracker",
-            "Email address that mail to roundup should go to."),
+            "Email address that mail to roundup should go to.\n"
+            "If no domain is specified then mail_domain is added."),
         (NullableOption, "language", "",
             "Default locale name for this tracker.\n"
             "If this option is not set, the language is determined\n"
@@ -606,7 +611,12 @@ SETTINGS = (
             "Allowed values: DEBUG, INFO, WARNING, ERROR"),
     )),
     ("mail", (
-        (Option, "domain", NODEFAULT, "Domain name used for email addresses."),
+        (Option, "domain", NODEFAULT,
+            "The email domain that admin_email, issue_tracker and\n"
+            "dispatcher_email belong to.\n"
+            "This domain is added to those config items if they don't\n"
+            "explicitly include a domain.\n"
+            "Do not include the '@' symbol."),
         (Option, "host", NODEFAULT,
             "SMTP mail host that roundup will use to send mail",
             ["MAILHOST"],),
