@@ -91,26 +91,41 @@ class HTMLClassTestCase(TemplatingTestCase) :
     def test_url_match(self):
         '''Test the URL regular expression in StringHTMLProperty.
         '''
-        def t(s, **groups):
+        def t(s, nothing=False, **groups):
             m = StringHTMLProperty.hyper_re.search(s)
-            self.assertNotEquals(m, None, '%r did not match'%s)
+            if nothing:
+                if m:
+                    self.assertEquals(m, None, '%r matched (%r)'%(s, m.groupdict()))
+                return
+            else:
+                self.assertNotEquals(m, None, '%r did not match'%s)
             d = m.groupdict()
             for g in groups:
                 self.assertEquals(d[g], groups[g], '%s %r != %r in %r'%(g, d[g],
                     groups[g], s))
 
         #t('123.321.123.321', 'url')
+        t('http://localhost/', url='http://localhost/')
         t('http://roundup.net/', url='http://roundup.net/')
+        t('http://richard@localhost/', url='http://richard@localhost/')
+        t('http://richard:sekrit@localhost/',
+            url='http://richard:sekrit@localhost/')
         t('<HTTP://roundup.net/>', url='HTTP://roundup.net/')
         t('www.a.ex', url='www.a.ex')
+        t('foo.a.ex', nothing=True)
+        t('StDevValidTimeSeries.GetObservation', nothing=True)
         t('http://a.ex', url='http://a.ex')
         t('http://a.ex/?foo&bar=baz\\.@!$%()qwerty',
             url='http://a.ex/?foo&bar=baz\\.@!$%()qwerty')
-        t('www.net', url='www.net')
+        t('www.foo.net', url='www.foo.net')
         t('richard@com.example', email='richard@com.example')
         t('r@a.com', email='r@a.com')
         t('i1', **{'class':'i', 'id':'1'})
         t('item123', **{'class':'item', 'id':'123'})
+        t('www.user:pass@host.net', email='pass@host.net')
+        t('user:pass@www.host.net', url='user:pass@www.host.net')
+        t('123.35', nothing=True)
+        t('-.3535', nothing=True)
 
     def test_url_replace(self):
         p = StringHTMLProperty(self.client, 'test', '1', None, 'test', '')
